@@ -13,14 +13,25 @@ from rayvision_utils.cmd import Cmd
 from rayvision_utils.exception import tips_code
 from rayvision_utils.exception.error_msg import ERROR9899_CGEXE_NOTEXIST
 from rayvision_utils.exception.exception import CGFileNotExistsError, AnalyseFailError, CGExeNotExistError
-
+from rayvision_katana.constants import PACKAGE_NAME
 
 class AnalyzeKatana(object):
-    def __init__(self, cg_file, software_version, project_name,
-                 plugin_config, render_software="Katana",
-                 input_project_path=None, local_os=None, workspace=None,
+    def __init__(self,
+                 cg_file,
+                 software_version,
+                 project_name,
+                 plugin_config,
+                 render_software="Katana",
+                 input_project_path=None,
+                 local_os=None,
+                 workspace=None,
                  custom_exe_path=None,
-                 platform="2"):
+                 platform="2",
+                 logger=None,
+                 log_folder=None,
+                 log_name=None,
+                 log_level="DEBUG"
+                 ):
         """Initialize and examine the analysis information.
 
         Args:
@@ -34,9 +45,17 @@ class AnalyzeKatana(object):
             workspace (str): Analysis out of the result file storage path.
             custom_exe_path (str): Customize the exe path for the analysis.
             platform (str): Platform no.
-
+            logger (object, optional): Custom log object.
+            log_folder (str, optional): Custom log save location.
+            log_name (str, optional): Custom log file name.
+            log_level (string):  Set log level, example: "DEBUG","INFO","WARNING","ERROR".
         """
-        self.logger = logging.getLogger(__name__)
+        self.logger = logger
+        if not self.logger:
+            from rayvision_log.core import init_logger
+            init_logger(PACKAGE_NAME, log_folder, log_name)
+            self.logger = logging.getLogger(__name__)
+            self.logger.setLevel(level=log_level.upper())
 
         self.check_path(cg_file)
         self.cg_file = cg_file
